@@ -22,20 +22,28 @@ config_file = os.path.join(expanduser("~"), ".wcscfg")
 
 _session = None
 def __return_wrapper(resp):
-    if resp.text != '':
-        resp_header = {'x-reqid': resp.headers['x-reqid']}
-        try:
-            return resp.status_code, json.loads(str(resp.text)), resp_header
-        except Exception as e:
-            response_body = yaml.load(resp.text)
-            if 'code' in response_body.keys():
-                return response_body["code"],response_body,resp_header
+    try:
+        if resp.text != '':
+            if 'X-Reqid' in resp.headers.keys():
+                resp_header = {'x-reqid': resp.headers['X-Reqid']}
             else:
-                return -2, {'message':resp.text}, resp_header
-    else:
-        resp_header = resp.headers
-        return -2, {'message':'Message Body is None. Please check your URL.'}, resp_header
-        
+                resp_header = {'x-reqid': 'None'}
+            try:
+                return resp.status_code, json.loads(str(resp.text)), resp_header
+            except Exception as e:
+                response_body = yaml.load(resp.text)
+                if 'code' in response_body.keys():
+                    return response_body["code"],response_body,resp_header
+                else:
+                    return -2, {'message':resp.text}, resp_header
+        else:
+            if resp.status_code == 303:
+                resp_header = {'x-reqid': resp.headers['X-Reqid']}
+                return resp.status_code, resp.headers['Location'], resp_header
+            resp_header = resp.headers
+            return -2, {'message':'Message Body is None. Please check your URL.'}, resp_header
+    except Exception as error:
+        return -2, {'message':'Some abnormal error occurred on the server.'}, {'x-reqid': 'None'}
 
 def _init():
     session = requests.Session()
@@ -59,9 +67,15 @@ def _post(url, headers, data=None, files=None):
             _session.keep_alive = False
             headers['Connection'] = 'close'
         if cfg.isverify:
-            r = _session.post(url=url, data=data, files=files, headers=headers, timeout=timeout, verify=True)
+            if cfg.returnUrl:
+                r = _session.post(url=url, data=data, files=files, headers=headers, timeout=timeout, verify=True, allow_redirects=False)
+            else:
+                r = _session.post(url=url, data=data, files=files, headers=headers, timeout=timeout, verify=True)
         else:
-            r = _session.post(url=url, data=data, files=files, headers=headers, timeout=timeout, verify=False)
+            if cfg.returnUrl:
+                r = _session.post(url=url, data=data, files=files, headers=headers, timeout=timeout, verify=False, allow_redirects=False)
+            else:
+                r = _session.post(url=url, data=data, files=files, headers=headers, timeout=timeout, verify=False)
     except Exception as e:
         errormessage = {'message':str(e)}
         return -1,errormessage,'None'
