@@ -1,12 +1,12 @@
 #!/usr/bin/python
 ## -*- coding: utf-8 -*-
 
-from wcs.services.mgrbase import MgrBase
-from wcs.commons.http import _post
 from wcs.commons.http import _get
-from wcs.commons.util import urlsafe_base64_encode,https_check
+from wcs.commons.http import _post
+from wcs.commons.logme import debug
+from wcs.commons.util import https_check
+from wcs.services.mgrbase import MgrBase
 
-from wcs.commons.logme import debug, error
 
 class Fmgr(MgrBase):
     """高级资源管理类
