@@ -1,13 +1,17 @@
-from wcs.services.mgrbase import MgrBase
+#!/usr/bin/python
+## -*- coding: utf-8 -*-
 from wcs.commons.config import Config
 from wcs.commons.http import _get
-from wcs.commons.logme import debug,error 
+from wcs.commons.logme import debug
 from wcs.commons.util import https_check
+from wcs.services.mgrbase import MgrBase
 
 MGR = Config.mgr_url
 
 class WsLive(MgrBase):
-
+    """直播录制文件查询类
+    该类继承自mgrbase
+    """
     def __init__(self, auth,url):
         super(WsLive, self).__init__(auth,url)
 
